==> imp-doc-2.0.1.tar.gz: html/classIMP_1_1multifit_1_1ComponentHeader.js <==
var classIMP_1_1multifit_1_1ComponentHeader =
[
    [ "ComponentHeader", "classIMP_1_1multifit_1_1ComponentHeader.html#a6363ab1941f7ccff19cb482166eb80f5", null ],
    [ "get_filename", "classIMP_1_1multifit_1_1ComponentHeader.html#a8d8d1efda593f3befffd02b526bfa84e", null ],
    [ "get_name", "classIMP_1_1multifit_1_1ComponentHeader.html#ab920239e3c7d8b62cd8db0f4238eae44", null ],
    [ "get_num_ap", "classIMP_1_1multifit_1_1ComponentHeader.html#a918b0831168580c3539293e3200da595", null ],
    [ "get_num_fine_ap", "classIMP_1_1multifit_1_1ComponentHeader.html#af049e19470049bb7d2659904202a5082", null ],
    [ "get_reference_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#a4b624966ac038d69c328565d245c60d2", null ],
    [ "get_surface_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#a58d3eea89e6b7bf0e6fe632454ec4eb1", null ],
    [ "get_transformations_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#a83f11d789c248ca9ce44e3dd5c2d3921", null ],
    [ "get_txt_ap_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#ab15560347613050f9c122a9e558d9508", null ],
    [ "get_txt_fine_ap_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#a43b30b3571baa8cfb075ec45422ea1e6", null ],
    [ "set_filename", "classIMP_1_1multifit_1_1ComponentHeader.html#a3177e09dc25177314957f401c372ba64", null ],
    [ "set_name", "classIMP_1_1multifit_1_1ComponentHeader.html#ad68196ccee1a2cb456aadd5f0fe349bb", null ],
    [ "set_num_ap", "classIMP_1_1multifit_1_1ComponentHeader.html#ae49277761fb9a46977978d4da08eebe4", null ],
    [ "set_num_fine_ap", "classIMP_1_1multifit_1_1ComponentHeader.html#ad21a41254c90dd226e051efc50481be9", null ],
    [ "set_reference_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#a8faadd8b23c04c081b8b48d46a99018a", null ],
    [ "set_surface_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#a15b19e906421a316ba1ab597280264a9", null ],
    [ "set_transformations_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#ad24e3d3ba6ad51c5e2ab591eb4f4c73c", null ],
    [ "set_txt_ap_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#a7bed0f99f5418b8f14dae4b6fc09dbe3", null ],
    [ "set_txt_fine_ap_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#a794866ea9cee6565f13f970e731a504b", null ],
    [ "ComponentHeadersTemp", "classIMP_1_1multifit_1_1ComponentHeader.html#a87088db59c7086e3b86b7607dce4db43", null ],
    [ "filename_", "classIMP_1_1multifit_1_1ComponentHeader.html#ac32b9fd7f8463bff8d4d5f9f0a3cf29a", null ],
    [ "name_", "classIMP_1_1multifit_1_1ComponentHeader.html#a5ec75bcaaca73506440e3946c5fbb4b4", null ],
    [ "num_ap_", "classIMP_1_1multifit_1_1ComponentHeader.html#a5c2bcf176f32ebe8fd0ef6247e02daae", null ],
    [ "num_fine_ap_", "classIMP_1_1multifit_1_1ComponentHeader.html#a2287c136c3102ab8ad66cf1542c43cbf", null ],
    [ "pdb_ap_fn_", "classIMP_1_1multifit_1_1ComponentHeader.html#a660a6c3d12359076b584546e2d7bbada", null ],
    [ "pdb_fine_ap_fn_", "classIMP_1_1multifit_1_1ComponentHeader.html#a16394e571bcf943133b96b68ed8cfadf", null ],
    [ "reference_fn_", "classIMP_1_1multifit_1_1ComponentHeader.html#a56dfc44cfff83b3b01454a1964855d59", null ],
    [ "surface_fn_", "classIMP_1_1multifit_1_1ComponentHeader.html#a34da55d379a71a37fc12ceb6f494ec0c", null ],
    [ "transformations_fn_", "classIMP_1_1multifit_1_1ComponentHeader.html#a497ef533895e7edb02f9579ea11ffe78", null ]
];

==> imp-doc-2.1.1.tar.gz: html/classIMP_1_1multifit_1_1ComponentHeader.js <==
var classIMP_1_1multifit_1_1ComponentHeader =
[
    [ "ComponentHeader", "classIMP_1_1multifit_1_1ComponentHeader.html#a6363ab1941f7ccff19cb482166eb80f5", null ],
    [ "get_filename", "classIMP_1_1multifit_1_1ComponentHeader.html#a8d8d1efda593f3befffd02b526bfa84e", null ],
    [ "get_name", "classIMP_1_1multifit_1_1ComponentHeader.html#ab920239e3c7d8b62cd8db0f4238eae44", null ],
    [ "get_num_ap", "classIMP_1_1multifit_1_1ComponentHeader.html#a918b0831168580c3539293e3200da595", null ],
    [ "get_num_fine_ap", "classIMP_1_1multifit_1_1ComponentHeader.html#af049e19470049bb7d2659904202a5082", null ],
    [ "get_reference_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#a4b624966ac038d69c328565d245c60d2", null ],
    [ "get_surface_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#a58d3eea89e6b7bf0e6fe632454ec4eb1", null ],
    [ "get_transformations_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#a83f11d789c248ca9ce44e3dd5c2d3921", null ],
    [ "get_txt_ap_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#ab15560347613050f9c122a9e558d9508", null ],
    [ "get_txt_fine_ap_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#a43b30b3571baa8cfb075ec45422ea1e6", null ],
    [ "get_type_name", "classIMP_1_1multifit_1_1ComponentHeader.html#a156ac325aee47f52535eda57f8f7d44c", null ],
    [ "get_version_info", "classIMP_1_1multifit_1_1ComponentHeader.html#adda4ac35f37f575b296a2b86aa11289e", null ],
    [ "set_filename", "classIMP_1_1multifit_1_1ComponentHeader.html#a3177e09dc25177314957f401c372ba64", null ],
    [ "set_name", "classIMP_1_1multifit_1_1ComponentHeader.html#ad68196ccee1a2cb456aadd5f0fe349bb", null ],
    [ "set_num_ap", "classIMP_1_1multifit_1_1ComponentHeader.html#ae49277761fb9a46977978d4da08eebe4", null ],
    [ "set_num_fine_ap", "classIMP_1_1multifit_1_1ComponentHeader.html#ad21a41254c90dd226e051efc50481be9", null ],
    [ "set_reference_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#a8faadd8b23c04c081b8b48d46a99018a", null ],
    [ "set_surface_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#a15b19e906421a316ba1ab597280264a9", null ],
    [ "set_transformations_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#ad24e3d3ba6ad51c5e2ab591eb4f4c73c", null ],
    [ "set_txt_ap_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#a7bed0f99f5418b8f14dae4b6fc09dbe3", null ],
    [ "set_txt_fine_ap_fn", "classIMP_1_1multifit_1_1ComponentHeader.html#a794866ea9cee6565f13f970e731a504b", null ],
    [ "filename_", "classIMP_1_1multifit_1_1ComponentHeader.html#ac32b9fd7f8463bff8d4d5f9f0a3cf29a", null ],
    [ "name_", "classIMP_1_1multifit_1_1ComponentHeader.html#a5ec75bcaaca73506440e3946c5fbb4b4", null ],
    [ "num_ap_", "classIMP_1_1multifit_1_1ComponentHeader.html#a5c2bcf176f32ebe8fd0ef6247e02daae", null ],
    [ "num_fine_ap_", "classIMP_1_1multifit_1_1ComponentHeader.html#a2287c136c3102ab8ad66cf1542c43cbf", null ],
    [ "pdb_ap_fn_", "classIMP_1_1multifit_1_1ComponentHeader.html#a660a6c3d12359076b584546e2d7bbada", null ],
    [ "pdb_fine_ap_fn_", "classIMP_1_1multifit_1_1ComponentHeader.html#a16394e571bcf943133b96b68ed8cfadf", null ],
    [ "reference_fn_", "classIMP_1_1multifit_1_1ComponentHeader.html#a56dfc44cfff83b3b01454a1964855d59", null ],
    [ "surface_fn_", "classIMP_1_1multifit_1_1ComponentHeader.html#a34da55d379a71a37fc12ceb6f494ec0c", null ],
    [ "transformations_fn_", "classIMP_1_1multifit_1_1ComponentHeader.html#a497ef533895e7edb02f9579ea11ffe78", null ]
];
